==> haskell-crypton-x509-system-1.6.7-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-G5JodxU0YwzL0FkUDiD1U
key:                  crypton-x509-system-1.6.7-G5JodxU0YwzL0FkUDiD1U
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  979f9496c20a81db2d7343106ecc36ee
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-G5JodxU0YwzL0FkUDiD1U
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-2ICUHbTMT5WIiBAYdHLRSn
    crypton-x509-store-1.6.11-AriKZr3mgUx2cgw1LULRv directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-Fwmaxlk6vsh4DoB0HUSpK9
    process-1.6.18.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-system-1.6.7-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-6Md6d9Kp22ZKXpF7yhnvXw
key:                  crypton-x509-system-1.6.7-6Md6d9Kp22ZKXpF7yhnvXw
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  611d9250268a153ad070e85c1d07c20d
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-6Md6d9Kp22ZKXpF7yhnvXw
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-AQmb0y3mHO7FgNVZXhQaf6
    crypton-x509-store-1.6.11-HG0OtiuplxC8gPPIWlPhgr directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-72HQwt2fMguDm14LZDsFgS
    process-1.6.18.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
